==> AGXUnreal-1.17.0_UE-5.6_Win64.zip: Marketplace/AGXUnreal/Source/ThirdParty/agx/include/openplx/Physics/Signals/Position1DOutput.h <==
#pragma once
#include <openplx/Object.h>
#include <openplx/ExpressionEvaluator.h>
#include <memory>
#include <stdexcept>
#include <unordered_map>
#include <openplx/Physics/PhysicsForward.h>
#include <openplx/Math/MathForward.h>
#include <openplx/Physics/Signals/Output.h>
#include <openplx/Physics/Signals/Position1DOutputTrait.h>
/* Generated code for model Position1DOutput */
namespace openplx::Physics::Signals {
    /**
     * A scalar position output given an interaction.
     * For interactions where it is unambiguous which position is requested,
     * the output will give the current output value.
     **/
    class Position1DOutput : public openplx::Physics::Signals::Output {
        protected:
            std::weak_ptr<openplx::Physics::Signals::Position1DOutputTrait> m_source;

        public:
            Position1DOutput();
            std::shared_ptr<openplx::Physics::Signals::Position1DOutputTrait> source() const;
            void setDynamic(const std::string& key, openplx::Core::Any&& value) override;
            openplx::Core::Any getDynamic(const std::string& key) const override;
            openplx::Core::Any callDynamic(const std::string& key, const std::vector<openplx::Core::Any>& args) override;
            void extractObjectFieldsTo(std::vector<std::shared_ptr<openplx::Core::Object>>& output) const override;
            void extractEntriesTo(std::vector<std::pair<std::string, openplx::Core::Any>>& output) const override;
            void triggerOnInit(const openplx::RuntimeContext& context) override;
    };
}

==> AGXUnreal-2.1.1_UE-5.6_Win64.zip: Marketplace/AGXUnreal/Source/ThirdParty/agx/include/openplx/Physics/Signals/Position1DOutput.h <==
#pragma once
#include <openplx/Object.h>
#include <openplx/ExpressionEvaluator.h>
#include <memory>
#include <stdexcept>
#include <unordered_map>
#include <openplx/Physics/PhysicsBundleExport.h>
#include <openplx/Physics/PhysicsForward.h>
#include <openplx/Math/MathForward.h>
#include <openplx/Physics/Signals/Output.h>
#include <openplx/Physics/Signals/Position1DOutputTrait.h>

#ifdef _MSC_VER
#  pragma warning(push)
#  pragma warning(disable: 4251)
#endif

/* Generated code for model Position1DOutput */
namespace openplx::Physics::Signals {
    /**
     * A scalar position output given an interaction.
     * For interactions where it is unambiguous which position is requested,
     * the output will give the current output value.
     **/
    class OPENPLX_Physics_BUNDLE_EXPORT Position1DOutput : public openplx::Physics::Signals::Output {
        protected:
            std::weak_ptr<openplx::Physics::Signals::Position1DOutputTrait> m_source;

        public:
            Position1DOutput();
            virtual ~Position1DOutput();
            std::shared_ptr<openplx::Physics::Signals::Position1DOutputTrait> source() const;
            void setDynamic(const std::string& key, openplx::Core::Any&& value) override;
            openplx::Core::Any getDynamic(const std::string& key) const override;
            openplx::Core::Any callDynamic(const std::string& key, const std::vector<openplx::Core::Any>& args) override;
            void extractObjectFieldsTo(std::vector<std::shared_ptr<openplx::Core::Object>>& output) const override;
            void extractEntriesTo(std::vector<std::pair<std::string, openplx::Core::Any>>& output) const override;
            void triggerOnInit(const openplx::RuntimeContext& context) override;
    };
}

#ifdef _MSC_VER
#  pragma warning(pop)
#endif
